"""
Network configuration.

MicroPython module: https://docs.micropython.org/en/v1.26.0/library/network.html

This module provides network drivers and routing configuration. To use this
module, a MicroPython variant/build with network capabilities must be installed.
Network drivers for specific hardware are available within this module and are
used to configure hardware network interface(s). Network services provided
by configured interfaces are then available for use via the :mod:`socket`
module.

For example::

    # connect/ show IP config a specific network interface
    # see below for examples of specific drivers
    import network
    import time
    nic = network.Driver(...)
    if not nic.isconnected():
        nic.connect()
        print("Waiting for connection...")
        while not nic.isconnected():
            time.sleep(1)
    print(nic.ipconfig("addr4"))

    # now use socket as usual
    import socket
    addr = socket.getaddrinfo('micropython.org', 80)[0][-1]
    s = socket.socket()
    s.connect(addr)
    s.send(b'GET / HTTP/1.1

Host: micropython.org



')
    data = s.recv(1000)
    s.close()

---
Module: 'network' on micropython-v1.26.0-stm32-PYBV11-NETWORK
"""

# MCU: {'variant': 'NETWORK', 'build': '', 'arch': 'armv7emsp', 'port': 'stm32', 'board': 'PYBV11', 'board_id': 'PYBV11-NETWORK', 'mpy': 'v6.3', 'ver': '1.26.0', 'family': 'micropython', 'cpu': 'STM32F405RG', 'version': '1.26.0'}
# Stubber: v1.26.0
from __future__ import annotations
from typing import Optional, Protocol, Callable, List, Any, Tuple, overload, Final
from _typeshed import Incomplete
from typing_extensions import Awaitable, TypeAlias, TypeVar
from machine import Pin, SPI
from abc import abstractmethod

STA_IF: Final[int] = 0
AP_IF: Final[int] = 1

def route(*args, **kwargs) -> Incomplete: ...
def hostname(name: Optional[Any] = None) -> Incomplete:
    """
    Get or set the hostname that will identify this device on the network. It will
    be used by all interfaces.

    This hostname is used for:
     * Sending to the DHCP server in the client request. (If using DHCP)
     * Broadcasting via mDNS. (If enabled)

    If the *name* parameter is provided, the hostname will be set to this value.
    If the function is called without parameters, it returns the current
    hostname.

    A change in hostname is typically only applied during connection. For DHCP
    this is because the hostname is part of the DHCP client request, and the
    implementation of mDNS in most ports only initialises the hostname once
    during connection. For this reason, you must set the hostname before
    activating/connecting your network interfaces.

    The length of the hostname is limited to 32 characters.
    :term:`MicroPython ports <MicroPython port>` may choose to set a lower
    limit for memory reasons. If the given name does not fit, a `ValueError`
    is raised.

    The default hostname is typically the name of the board.
    """
    ...

def country(code: Optional[Any] = None) -> Incomplete:
    """
    Get or set the two-letter ISO 3166-1 Alpha-2 country code to be used for
    radio compliance.

    If the *code* parameter is provided, the country will be set to this value.
    If the function is called without parameters, it returns the current
    country.

    The default code ``"XX"`` represents the "worldwide" region.
    """
    ...

class WIZNET5K:
    """
    This class allows you to control WIZnet5x00 Ethernet adaptors based on
    the W5200 and W5500 chipsets.  The particular chipset that is supported
    by the firmware is selected at compile-time via the MICROPY_PY_WIZNET5K
    option.

    Example usage::

        import network
        nic = network.WIZNET5K(SPI(1), Pin.board.X5, Pin.board.X4)
        print(nic.ifconfig())

        # now use socket as usual
        ...

    For this example to work the WIZnet5x00 module must have the following connections:

        - MOSI connected to X8
        - MISO connected to X7
        - SCLK connected to X6
        - nSS connected to X5
        - nRESET connected to X4

    It is possible to use other SPI buses and other pins for nSS and nRESET.
    """

    def isconnected(self, *args, **kwargs) -> Incomplete: ...
    def status(self, *args, **kwargs) -> Incomplete: ...
    def regs(self) -> Any:
        """
        Dump the WIZnet5x00 registers.  Useful for debugging.
        """
        ...

    def active(self, *args, **kwargs) -> Incomplete: ...
    def ifconfig(self, *args, **kwargs) -> Incomplete: ...
    def config(self, *args, **kwargs) -> Incomplete: ...
    def __init__(self, spi: SPI, pin_cs: Pin, pin_rst: Pin, /) -> None:
        """
        Create a WIZNET5K driver object, initialise the WIZnet5x00 module using the given
        SPI bus and pins, and return the WIZNET5K object.

        Arguments are:

          - *spi* is an :ref:`SPI object <SPI>` which is the SPI bus that the WIZnet5x00 is
            connected to (the MOSI, MISO and SCLK pins).
          - *pin_cs* is a :ref:`Pin object <Pin>` which is connected to the WIZnet5x00 nSS pin.
          - *pin_rst* is a :ref:`Pin object <Pin>` which is connected to the WIZnet5x00 nRESET pin.

        All of these objects will be initialised by the driver, so there is no need to
        initialise them yourself.  For example, you can use::

          nic = network.WIZNET5K(SPI(1), Pin.board.X5, Pin.board.X4)
        """

class LAN:
    @overload
    def active(self, /) -> bool:
        """
        With a parameter, it sets the interface active if *state* is true, otherwise it
        sets it inactive.
        Without a parameter, it returns the state.
        """

    @overload
    def active(self, is_active: bool | int, /) -> None:
        """
        With a parameter, it sets the interface active if *state* is true, otherwise it
        sets it inactive.
        Without a parameter, it returns the state.
        """

class WLAN:
    @overload
    def active(self, /) -> bool:
        """
        Activate ("up") or deactivate ("down") network interface, if boolean
        argument is passed. Otherwise, query current state if no argument is
        provided. Most other methods require active interface.
        """

    @overload
    def active(self, is_active: bool | int, /) -> None:
        """
        Activate ("up") or deactivate ("down") network interface, if boolean
        argument is passed. Otherwise, query current state if no argument is
        provided. Most other methods require active interface.
        """

    @overload
    def status(self) -> int:
        """
        Return the current status of the wireless connection.

        When called with no argument the return value describes the network link status.
        The possible statuses are defined as constants in the :mod:`network` module:

            * ``STAT_IDLE`` -- no connection and no activity,
            * ``STAT_CONNECTING`` -- connecting in progress,
            * ``STAT_WRONG_PASSWORD`` -- failed due to incorrect password,
            * ``STAT_NO_AP_FOUND`` -- failed because no access point replied,
            * ``STAT_CONNECT_FAIL`` -- failed due to other problems,
            * ``STAT_GOT_IP`` -- connection successful.

        When called with one argument *param* should be a string naming the status
        parameter to retrieve, and different parameters are supported depending on the
        mode the WiFi is in.

        In STA mode, passing ``'rssi'`` returns a signal strength indicator value, whose
        format varies depending on the port (this is available on all ports that support
        WiFi network interfaces, except for CC3200).

        In AP mode, passing ``'stations'`` returns a list of connected WiFi stations
        (this is available on all ports that support WiFi network interfaces, except for
        CC3200).  The format of the station information entries varies across ports,
        providing either the raw BSSID of the connected station, the IP address of the
        connected station, or both.
        """

    @overload
    def status(self, param: str, /) -> int:
        """
        Return the current status of the wireless connection.

        When called with no argument the return value describes the network link status.
        The possible statuses are defined as constants in the :mod:`network` module:

            * ``STAT_IDLE`` -- no connection and no activity,
            * ``STAT_CONNECTING`` -- connecting in progress,
            * ``STAT_WRONG_PASSWORD`` -- failed due to incorrect password,
            * ``STAT_NO_AP_FOUND`` -- failed because no access point replied,
            * ``STAT_CONNECT_FAIL`` -- failed due to other problems,
            * ``STAT_GOT_IP`` -- connection successful.

        When called with one argument *param* should be a string naming the status
        parameter to retrieve, and different parameters are supported depending on the
        mode the WiFi is in.

        In STA mode, passing ``'rssi'`` returns a signal strength indicator value, whose
        format varies depending on the port (this is available on all ports that support
        WiFi network interfaces, except for CC3200).

        In AP mode, passing ``'stations'`` returns a list of connected WiFi stations
        (this is available on all ports that support WiFi network interfaces, except for
        CC3200).  The format of the station information entries varies across ports,
        providing either the raw BSSID of the connected station, the IP address of the
        connected station, or both.
        """

    @overload
    def ifconfig(self) -> tuple[str, str, str, str]:
        """
        Get/set IP-level network interface parameters: IP address, subnet mask,
        gateway and DNS server. When called with no arguments, this method returns
        a 4-tuple with the above information. To set the above values, pass a
        4-tuple with the required information.  For example::

         nic.ifconfig(('192.168.0.4', '255.255.255.0', '192.168.0.1', '8.8.8.8'))
        """

    @overload
    def ifconfig(self, ip_mask_gateway_dns: tuple[str, str, str, str], /) -> None:
        """
        Get/set IP-level network interface parameters: IP address, subnet mask,
        gateway and DNS server. When called with no arguments, this method returns
        a 4-tuple with the above information. To set the above values, pass a
        4-tuple with the required information.  For example::

         nic.ifconfig(('192.168.0.4', '255.255.255.0', '192.168.0.1', '8.8.8.8'))
        """

    @overload
    def config(self, param: str, /) -> Any:
        """
        Get or set general network interface parameters. These methods allow to work
        with additional parameters beyond standard IP configuration (as dealt with by
        `AbstractNIC.ipconfig()`). These include network-specific and hardware-specific
        parameters. For setting parameters, keyword argument syntax should be used,
        multiple parameters can be set at once. For querying, parameters name should
        be quoted as a string, and only one parameter can be queries at time::

         # Set WiFi access point name (formally known as SSID) and WiFi channel
         ap.config(ssid='My AP', channel=11)
         # Query params one by one
         print(ap.config('ssid'))
         print(ap.config('channel'))

        Following are commonly supported parameters (availability of a specific parameter
        depends on network technology type, driver, and :term:`MicroPython port`).

        =============  ===========
        Parameter      Description
        =============  ===========
        mac            MAC address (bytes)
        ssid           WiFi access point name (string)
        channel        WiFi channel (integer). Depending on the port this may only be supported on the AP interface.
        hidden         Whether SSID is hidden (boolean)
        security       Security protocol supported (enumeration, see module constants)
        key            Access key (string)
        hostname       The hostname that will be sent to DHCP (STA interfaces) and mDNS (if supported, both STA and AP). (Deprecated, use :func:`network.hostname` instead)
        reconnects     Number of reconnect attempts to make (integer, 0=none, -1=unlimited)
        txpower        Maximum transmit power in dBm (integer or float)
        pm             WiFi Power Management setting (see below for allowed values)
        =============  ===========
        """

    @overload
    def config(self, **kwargs: Any) -> None:
        """
        Get or set general network interface parameters. These methods allow to work
        with additional parameters beyond standard IP configuration (as dealt with by
        `AbstractNIC.ipconfig()`). These include network-specific and hardware-specific
        parameters. For setting parameters, keyword argument syntax should be used,
        multiple parameters can be set at once. For querying, parameters name should
        be quoted as a string, and only one parameter can be queries at time::

         # Set WiFi access point name (formally known as SSID) and WiFi channel
         ap.config(ssid='My AP', channel=11)
         # Query params one by one
         print(ap.config('ssid'))
         print(ap.config('channel'))

        Following are commonly supported parameters (availability of a specific parameter
        depends on network technology type, driver, and :term:`MicroPython port`).

        =============  ===========
        Parameter      Description
        =============  ===========
        mac            MAC address (bytes)
        ssid           WiFi access point name (string)
        channel        WiFi channel (integer). Depending on the port this may only be supported on the AP interface.
        hidden         Whether SSID is hidden (boolean)
        security       Security protocol supported (enumeration, see module constants)
        key            Access key (string)
        hostname       The hostname that will be sent to DHCP (STA interfaces) and mDNS (if supported, both STA and AP). (Deprecated, use :func:`network.hostname` instead)
        reconnects     Number of reconnect attempts to make (integer, 0=none, -1=unlimited)
        txpower        Maximum transmit power in dBm (integer or float)
        pm             WiFi Power Management setting (see below for allowed values)
        =============  ===========
        """

class WLANWiPy:
    @overload
    def __init__(self, id: int = 0, /):
        """
        Create a WLAN object, and optionally configure it. See `init()` for params of configuration.

        .. note::

        The ``WLAN`` constructor is special in the sense that if no arguments besides the id are given,
        it will return the already existing ``WLAN`` instance without re-configuring it. This is
        because ``WLAN`` is a system feature of the WiPy. If the already existing instance is not
        initialized it will do the same as the other constructors an will initialize it with default
        values.
        """

    @overload
    def __init__(
        self,
        id: int,
        /,
        *,
        mode: int,
        ssid: str,
        auth: tuple[str, str],
        channel: int,
        antenna: int,
    ):
        """
        Create a WLAN object, and optionally configure it. See `init()` for params of configuration.

        .. note::

        The ``WLAN`` constructor is special in the sense that if no arguments besides the id are given,
        it will return the already existing ``WLAN`` instance without re-configuring it. This is
        because ``WLAN`` is a system feature of the WiPy. If the already existing instance is not
        initialized it will do the same as the other constructors an will initialize it with default
        values.
        """

    @overload
    def mode(self) -> int:
        """
        Get or set the WLAN mode.
        """

    @overload
    def mode(self, mode: int, /) -> None:
        """
        Get or set the WLAN mode.
        """

    @overload
    def ssid(self) -> str:
        """
        Get or set the SSID when in AP mode.
        """

    @overload
    def ssid(self, ssid: str, /) -> None:
        """
        Get or set the SSID when in AP mode.
        """

    @overload
    def auth(self) -> int:
        """
        Get or set the authentication type when in AP mode.
        """

    @overload
    def auth(self, auth: int, /) -> None:
        """
        Get or set the authentication type when in AP mode.
        """

    @overload
    def channel(self) -> int:
        """
        Get or set the channel (only applicable in AP mode).
        """

    @overload
    def channel(self, channel: int, /) -> None:
        """
        Get or set the channel (only applicable in AP mode).
        """

    @overload
    def antenna(self) -> int:
        """
        Get or set the antenna type (external or internal).
        """

    @overload
    def antenna(self, antenna: int, /) -> None:
        """
        Get or set the antenna type (external or internal).
        """

    @overload
    def mac(self) -> bytes:
        """
        Get or set a 6-byte long bytes object with the MAC address.
        """

    @overload
    def mac(self, mac: bytes, /) -> None:
        """
        Get or set a 6-byte long bytes object with the MAC address.
        """

class AbstractNIC:
    @overload
    @abstractmethod
    def active(self, /) -> bool:
        """
        Activate ("up") or deactivate ("down") the network interface, if
        a boolean argument is passed. Otherwise, query current state if
        no argument is provided. Most other methods require an active
        interface (behaviour of calling them on inactive interface is
        undefined).
        """

    @overload
    @abstractmethod
    def active(self, is_active: bool | int, /) -> None:
        """
        Activate ("up") or deactivate ("down") the network interface, if
        a boolean argument is passed. Otherwise, query current state if
        no argument is provided. Most other methods require an active
        interface (behaviour of calling them on inactive interface is
        undefined).
        """

    @overload
    @abstractmethod
    def connect(self, key: str | None = None, /, **kwargs: Any) -> None:
        """
        Connect the interface to a network. This method is optional, and
        available only for interfaces which are not "always connected".
        If no parameters are given, connect to the default (or the only)
        service. If a single parameter is given, it is the primary identifier
        of a service to connect to. It may be accompanied by a key
        (password) required to access said service. There can be further
        arbitrary keyword-only parameters, depending on the networking medium
        type and/or particular device. Parameters can be used to: a)
        specify alternative service identifier types; b) provide additional
        connection parameters. For various medium types, there are different
        sets of predefined/recommended parameters, among them:

        * WiFi: *bssid* keyword to connect to a specific BSSID (MAC address)
        """

    @overload
    @abstractmethod
    def connect(self, service_id: Any, key: str | None = None, /, **kwargs: Any) -> None:
        """
        Connect the interface to a network. This method is optional, and
        available only for interfaces which are not "always connected".
        If no parameters are given, connect to the default (or the only)
        service. If a single parameter is given, it is the primary identifier
        of a service to connect to. It may be accompanied by a key
        (password) required to access said service. There can be further
        arbitrary keyword-only parameters, depending on the networking medium
        type and/or particular device. Parameters can be used to: a)
        specify alternative service identifier types; b) provide additional
        connection parameters. For various medium types, there are different
        sets of predefined/recommended parameters, among them:

        * WiFi: *bssid* keyword to connect to a specific BSSID (MAC address)
        """

    @overload
    @abstractmethod
    def status(self) -> Any:
        """
        Query dynamic status information of the interface.  When called with no
        argument the return value describes the network link status.  Otherwise
        *param* should be a string naming the particular status parameter to
        retrieve.

        The return types and values are dependent on the network
        medium/technology.  Some of the parameters that may be supported are:

        * WiFi STA: use ``'rssi'`` to retrieve the RSSI of the AP signal
        * WiFi AP: use ``'stations'`` to retrieve a list of all the STAs
          connected to the AP.  The list contains tuples of the form
          (MAC, RSSI).
        """

    @overload
    @abstractmethod
    def status(self, param: str, /) -> Any:
        """
        Query dynamic status information of the interface.  When called with no
        argument the return value describes the network link status.  Otherwise
        *param* should be a string naming the particular status parameter to
        retrieve.

        The return types and values are dependent on the network
        medium/technology.  Some of the parameters that may be supported are:

        * WiFi STA: use ``'rssi'`` to retrieve the RSSI of the AP signal
        * WiFi AP: use ``'stations'`` to retrieve a list of all the STAs
          connected to the AP.  The list contains tuples of the form
          (MAC, RSSI).
        """

    @overload
    @abstractmethod
    def ifconfig(self) -> tuple[str, str, str, str]:
        """
        ``Note:`` This function is deprecated, use `ipconfig()` instead.

        Get/set IP-level network interface parameters: IP address, subnet mask,
        gateway and DNS server. When called with no arguments, this method returns
        a 4-tuple with the above information. To set the above values, pass a
        4-tuple with the required information.  For example::

         nic.ifconfig(('192.168.0.4', '255.255.255.0', '192.168.0.1', '8.8.8.8'))
        """

    @overload
    @abstractmethod
    def ifconfig(self, ip_mask_gateway_dns: tuple[str, str, str, str], /) -> None:
        """
        ``Note:`` This function is deprecated, use `ipconfig()` instead.

        Get/set IP-level network interface parameters: IP address, subnet mask,
        gateway and DNS server. When called with no arguments, this method returns
        a 4-tuple with the above information. To set the above values, pass a
        4-tuple with the required information.  For example::

         nic.ifconfig(('192.168.0.4', '255.255.255.0', '192.168.0.1', '8.8.8.8'))
        """

    @overload
    @abstractmethod
    def config(self, param: str, /) -> Any:
        """
        Get or set general network interface parameters. These methods allow to work
        with additional parameters beyond standard IP configuration (as dealt with by
        `ipconfig()`). These include network-specific and hardware-specific
        parameters. For setting parameters, the keyword argument
        syntax should be used, and multiple parameters can be set at once. For
        querying, a parameter name should be quoted as a string, and only one
        parameter can be queried at a time::

         # Set WiFi access point name (formally known as SSID) and WiFi channel
         ap.config(ssid='My AP', channel=11)
         # Query params one by one
         print(ap.config('ssid'))
         print(ap.config('channel'))
        """

    @overload
    @abstractmethod
    def config(self, **kwargs: Any) -> None:
        """
        Get or set general network interface parameters. These methods allow to work
        with additional parameters beyond standard IP configuration (as dealt with by
        `ipconfig()`). These include network-specific and hardware-specific
        parameters. For setting parameters, the keyword argument
        syntax should be used, and multiple parameters can be set at once. For
        querying, a parameter name should be quoted as a string, and only one
        parameter can be queried at a time::

         # Set WiFi access point name (formally known as SSID) and WiFi channel
         ap.config(ssid='My AP', channel=11)
         # Query params one by one
         print(ap.config('ssid'))
         print(ap.config('channel'))
        """



"""
Module: 'uheapq' on micropython-v1.26.0-stm32-PYBV11-NETWORK
"""

# MCU: {'variant': 'NETWORK', 'build': '', 'arch': 'armv7emsp', 'port': 'stm32', 'board': 'PYBV11', 'board_id': 'PYBV11-NETWORK', 'mpy': 'v6.3', 'ver': '1.26.0', 'family': 'micropython', 'cpu': 'STM32F405RG', 'version': '1.26.0'}
# Stubber: v1.26.0
from __future__ import annotations
from typing import Any, Final, Generator
from _typeshed import Incomplete

def heappop(*args, **kwargs) -> Incomplete: ...
def heappush(*args, **kwargs) -> Incomplete: ...
def heapify(*args, **kwargs) -> Incomplete: ...



"""
Functionality specific to STM32 MCUs.

MicroPython module: https://docs.micropython.org/en/v1.26.0/library/stm.html

This module provides functionality specific to STM32 microcontrollers, including
direct access to peripheral registers.

---
Module: 'stm' on micropython-v1.26.0-stm32-PYBV11-NETWORK
"""

# MCU: {'variant': 'NETWORK', 'build': '', 'arch': 'armv7emsp', 'port': 'stm32', 'board': 'PYBV11', 'board_id': 'PYBV11-NETWORK', 'mpy': 'v6.3', 'ver': '1.26.0', 'family': 'micropython', 'cpu': 'STM32F405RG', 'version': '1.26.0'}
# Stubber: v1.26.0
from __future__ import annotations
from typing import Tuple, Final
from _typeshed import Incomplete
from typing_extensions import Awaitable, TypeAlias, TypeVar

SPI_I2SPR: Final[int] = 32
RTC_DR: Final[int] = 4
RTC_CR: Final[int] = 8
RTC_CALR: Final[int] = 60
RTC_ISR: Final[int] = 12
RTC_SSR: Final[int] = 40
RTC_SHIFTR: Final[int] = 44
RTC_PRER: Final[int] = 16
RTC_CALIBR: Final[int] = 24
RTC_BKP5R: Final[int] = 100
RTC_BKP4R: Final[int] = 96
RTC_BKP3R: Final[int] = 92
RTC_BKP6R: Final[int] = 104
RTC_BKP9R: Final[int] = 116
RTC_BKP8R: Final[int] = 112
RTC_BKP7R: Final[int] = 108
RTC_TAFCR: Final[int] = 64
SPI_CR1: Final[int] = 0
SPI3: Final[int] = 1073757184
SPI2: Final[int] = 1073756160
SPI_CR2: Final[int] = 4
SPI_I2SCFGR: Final[int] = 28
SPI_DR: Final[int] = 12
SPI_CRCPR: Final[int] = 16
SPI1: Final[int] = 1073819648
RTC_TSSSR: Final[int] = 56
RTC_TSDR: Final[int] = 52
RTC_TR: Final[int] = 0
RTC_TSTR: Final[int] = 48
SDIO: Final[int] = 1073818624
RTC_WUTR: Final[int] = 20
RTC_WPR: Final[int] = 36
RTC_BKP2R: Final[int] = 88
RNG: Final[int] = 1342572544
RCC_SSCGR: Final[int] = 128
RCC_PLLI2SCFGR: Final[int] = 132
RNG_CR: Final[int] = 0
RTC: Final[int] = 1073752064
RNG_SR: Final[int] = 4
RNG_DR: Final[int] = 8
RCC_PLLCFGR: Final[int] = 4
RCC_BDCR: Final[int] = 112
RCC_APB2RSTR: Final[int] = 36
RCC_APB2LPENR: Final[int] = 100
RCC_CFGR: Final[int] = 8
RCC_CSR: Final[int] = 116
RCC_CR: Final[int] = 0
RCC_CIR: Final[int] = 12
RTC_ALRMAR: Final[int] = 28
RTC_BKP16R: Final[int] = 144
RTC_BKP15R: Final[int] = 140
RTC_BKP14R: Final[int] = 136
RTC_BKP17R: Final[int] = 148
RTC_BKP1R: Final[int] = 84
RTC_BKP19R: Final[int] = 156
RTC_BKP18R: Final[int] = 152
RTC_BKP13R: Final[int] = 132
RTC_ALRMBSSR: Final[int] = 72
RTC_ALRMBR: Final[int] = 32
RTC_ALRMASSR: Final[int] = 68
RTC_BKP0R: Final[int] = 80
RTC_BKP12R: Final[int] = 128
RTC_BKP11R: Final[int] = 124
RTC_BKP10R: Final[int] = 120
WWDG_SR: Final[int] = 8
SPI_RXCRCR: Final[int] = 20
TIM_RCR: Final[int] = 48
TIM_PSC: Final[int] = 40
TIM_OR: Final[int] = 80
TIM_SMCR: Final[int] = 8
UART5: Final[int] = 1073762304
UART4: Final[int] = 1073761280
TIM_SR: Final[int] = 16
TIM_EGR: Final[int] = 20
TIM_CR1: Final[int] = 0
TIM_CNT: Final[int] = 36
TIM_CCR4: Final[int] = 64
TIM_CR2: Final[int] = 4
TIM_DMAR: Final[int] = 76
TIM_DIER: Final[int] = 12
TIM_DCR: Final[int] = 72
USART1: Final[int] = 1073811456
USB_OTG_FS: Final[int] = 1342177280
USART_SR: Final[int] = 0
USART_GTPR: Final[int] = 24
USB_OTG_HS: Final[int] = 1074003968
WWDG_CR: Final[int] = 0
WWDG_CFR: Final[int] = 4
WWDG: Final[int] = 1073753088
USART_DR: Final[int] = 4
USART6: Final[int] = 1073812480
USART3: Final[int] = 1073760256
USART2: Final[int] = 1073759232
USART_BRR: Final[int] = 8
USART_CR3: Final[int] = 20
USART_CR2: Final[int] = 16
USART_CR1: Final[int] = 12
TIM_CCR3: Final[int] = 60
TIM1: Final[int] = 1073807360
SYSCFG_PMC: Final[int] = 4
SYSCFG_MEMRMP: Final[int] = 0
TIM10: Final[int] = 1073824768
TIM13: Final[int] = 1073748992
TIM12: Final[int] = 1073747968
TIM11: Final[int] = 1073825792
SYSCFG_EXTICR3: Final[int] = 20
SYSCFG: Final[int] = 1073821696
SPI_TXCRCR: Final[int] = 24
SPI_SR: Final[int] = 8
SYSCFG_CMPCR: Final[int] = 32
SYSCFG_EXTICR2: Final[int] = 16
SYSCFG_EXTICR1: Final[int] = 12
SYSCFG_EXTICR0: Final[int] = 8
TIM14: Final[int] = 1073750016
TIM_CCER: Final[int] = 32
TIM_BDTR: Final[int] = 68
TIM_ARR: Final[int] = 44
TIM_CCMR1: Final[int] = 24
TIM_CCR2: Final[int] = 56
TIM_CCR1: Final[int] = 52
TIM_CCMR2: Final[int] = 28
TIM9: Final[int] = 1073823744
TIM4: Final[int] = 1073743872
TIM3: Final[int] = 1073742848
TIM2: Final[int] = 1073741824
TIM5: Final[int] = 1073744896
TIM8: Final[int] = 1073808384
TIM7: Final[int] = 1073746944
TIM6: Final[int] = 1073745920
EXTI_SWIER: Final[int] = 16
DAC_DOR1: Final[int] = 44
DAC_DHR8RD: Final[int] = 40
DAC_DHR8R2: Final[int] = 28
DAC_DOR2: Final[int] = 48
DBGMCU: Final[int] = 3758366720
DAC_SWTRIGR: Final[int] = 4
DAC_SR: Final[int] = 52
DAC_DHR8R1: Final[int] = 16
DAC_DHR12L2: Final[int] = 24
DAC_DHR12L1: Final[int] = 12
DAC_CR: Final[int] = 0
DAC_DHR12LD: Final[int] = 36
DAC_DHR12RD: Final[int] = 32
DAC_DHR12R2: Final[int] = 20
DAC_DHR12R1: Final[int] = 8
DBGMCU_APB1FZ: Final[int] = 8
EXTI_EMR: Final[int] = 4
EXTI: Final[int] = 1073822720
DMA_LISR: Final[int] = 0
EXTI_FTSR: Final[int] = 12
EXTI_RTSR: Final[int] = 8
EXTI_PR: Final[int] = 20
EXTI_IMR: Final[int] = 0
DMA_LIFCR: Final[int] = 8
DBGMCU_IDCODE: Final[int] = 0
DBGMCU_CR: Final[int] = 4
DBGMCU_APB2FZ: Final[int] = 12
DMA1: Final[int] = 1073897472
DMA_HISR: Final[int] = 4
DMA_HIFCR: Final[int] = 12
DMA2: Final[int] = 1073898496
DAC1: Final[int] = 1073771520
ADC_JDR3: Final[int] = 68
ADC_JDR2: Final[int] = 64
ADC_JDR1: Final[int] = 60
ADC_JDR4: Final[int] = 72
ADC_JOFR3: Final[int] = 28
ADC_JOFR2: Final[int] = 24
ADC_JOFR1: Final[int] = 20
ADC_HTR: Final[int] = 36
ADC2: Final[int] = 1073815808
ADC123_COMMON: Final[int] = 1073816320
ADC1: Final[int] = 1073815552
ADC3: Final[int] = 1073816064
ADC_DR: Final[int] = 76
ADC_CR2: Final[int] = 8
ADC_CR1: Final[int] = 4
ADC_JOFR4: Final[int] = 32
CRC: Final[int] = 1073885184
CAN2: Final[int] = 1073768448
CAN1: Final[int] = 1073767424
CRC_CR: Final[int] = 8
DAC: Final[int] = 1073771520
CRC_IDR: Final[int] = 4
CRC_DR: Final[int] = 0
ADC_SR: Final[int] = 0
ADC_SMPR1: Final[int] = 12
ADC_LTR: Final[int] = 40
ADC_JSQR: Final[int] = 56
ADC_SMPR2: Final[int] = 16
ADC_SQR3: Final[int] = 52
ADC_SQR2: Final[int] = 48
ADC_SQR1: Final[int] = 44
RCC_APB2ENR: Final[int] = 68
FLASH: Final[int] = 1073888256
IWDG: Final[int] = 1073754112
I2S3EXT: Final[int] = 1073758208
I2S2EXT: Final[int] = 1073755136
IWDG_KR: Final[int] = 0
IWDG_SR: Final[int] = 12
IWDG_RLR: Final[int] = 8
IWDG_PR: Final[int] = 4
I2C_TRISE: Final[int] = 32
I2C_DR: Final[int] = 16
I2C_CR2: Final[int] = 4
I2C_CR1: Final[int] = 0
I2C_OAR1: Final[int] = 8
I2C_SR2: Final[int] = 24
I2C_SR1: Final[int] = 20
I2C_OAR2: Final[int] = 12
PWR: Final[int] = 1073770496
RCC_AHB3LPENR: Final[int] = 88
RCC_AHB3ENR: Final[int] = 56
RCC_AHB2RSTR: Final[int] = 20
RCC_AHB3RSTR: Final[int] = 24
RCC_APB1RSTR: Final[int] = 32
RCC_APB1LPENR: Final[int] = 96
RCC_APB1ENR: Final[int] = 64
RCC_AHB2LPENR: Final[int] = 84
RCC: Final[int] = 1073887232
PWR_CSR: Final[int] = 4
PWR_CR: Final[int] = 0
RCC_AHB1ENR: Final[int] = 48
RCC_AHB2ENR: Final[int] = 52
RCC_AHB1RSTR: Final[int] = 16
RCC_AHB1LPENR: Final[int] = 80
I2C_CCR: Final[int] = 28
GPIOD: Final[int] = 1073875968
GPIOC: Final[int] = 1073874944
GPIOB: Final[int] = 1073873920
GPIOE: Final[int] = 1073876992
GPIOH: Final[int] = 1073880064
GPIOG: Final[int] = 1073879040
GPIOF: Final[int] = 1073878016
GPIOA: Final[int] = 1073872896
FLASH_KEYR: Final[int] = 4
FLASH_CR: Final[int] = 16
FLASH_ACR: Final[int] = 0
FLASH_OPTCR: Final[int] = 20
FLASH_SR: Final[int] = 12
FLASH_OPTKEYR: Final[int] = 8
FLASH_OPTCR1: Final[int] = 24
GPIOI: Final[int] = 1073881088
GPIO_OTYPER: Final[int] = 4
GPIO_OSPEEDR: Final[int] = 8
GPIO_ODR: Final[int] = 20
GPIO_PUPDR: Final[int] = 12
I2C3: Final[int] = 1073765376
I2C2: Final[int] = 1073764352
I2C1: Final[int] = 1073763328
GPIO_MODER: Final[int] = 0
GPIO_BSRR: Final[int] = 24
GPIO_AFR1: Final[int] = 36
GPIO_AFR0: Final[int] = 32
GPIO_BSRRH: Final[int] = 26
GPIO_LCKR: Final[int] = 28
GPIO_IDR: Final[int] = 16
GPIO_BSRRL: Final[int] = 24
mem32: Incomplete  ## <class 'mem'> = <32-bit memory>
mem8: Incomplete  ## <class 'mem'> = <8-bit memory>
mem16: Incomplete  ## <class 'mem'> = <16-bit memory>
